From: = Yan Lei <yan_lei@dahuatech.com>
Date: Fri, 25 Mar 2022 15:50:00 +0800
Subject: [PATCH] Fix CWE-404: Leak of memory or pointers

dahua inclusion
category: bugfix
bugzilla: https://gitee.com/openeuler/kernel/issues/I4ZKXP
CVE: NA

----------------------------------------------------------
Leak of memory or pointers to system resources(CWE-404)

Signed-off-by: Yan Lei <yan_lei@dahuatech.com>
---
 drivers/media/dvb-frontends/bcm3510.c          | 1 +
 drivers/net/ethernet/netswift/txgbe/txgbe_hw.c | 1 +
 drivers/net/wireless/marvell/mwifiex/pcie.c    | 5 ++++-
 drivers/scsi/fcoe/fcoe.c                       | 1 +
 4 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/drivers/media/dvb-frontends/bcm3510.c b/drivers/media/dvb-frontends/bcm3510.c
index da0ff7b44..68b92b441
--- a/drivers/media/dvb-frontends/bcm3510.c
+++ b/drivers/media/dvb-frontends/bcm3510.c
@@ -649,6 +649,7 @@ static int bcm3510_download_firmware(struct dvb_frontend* fe)
 		deb_info("firmware chunk, addr: 0x%04x, len: 0x%04x, total length: 0x%04zx\n",addr,len,fw->size);
 		if ((ret = bcm3510_write_ram(st,addr,&b[i+4],len)) < 0) {
 			err("firmware download failed: %d\n",ret);
+			release_firmware(fw);
 			return ret;
 		}
 		i += 4 + len;
diff --git a/drivers/net/ethernet/netswift/txgbe/txgbe_hw.c b/drivers/net/ethernet/netswift/txgbe/txgbe_hw.c
index bbda30b75..15978ca1f 100755
--- a/drivers/net/ethernet/netswift/txgbe/txgbe_hw.c
+++ b/drivers/net/ethernet/netswift/txgbe/txgbe_hw.c
@@ -6794,6 +6794,7 @@ s32 txgbe_calc_eeprom_checksum(struct txgbe_hw *hw)
 						     eeprom_ptrs);
 		if (status) {
 			DEBUGOUT("Failed to read EEPROM image\n");
+			vfree(eeprom_ptrs);
 			return status;
 		}
 		local_buffer = eeprom_ptrs;
diff --git a/drivers/net/wireless/marvell/mwifiex/pcie.c b/drivers/net/wireless/marvell/mwifiex/pcie.c
index 7c137eba8..69aa044e6
--- a/drivers/net/wireless/marvell/mwifiex/pcie.c
+++ b/drivers/net/wireless/marvell/mwifiex/pcie.c
@@ -795,6 +795,7 @@ static int mwifiex_init_rxq_ring(struct mwifiex_adapter *adapter)
 			mwifiex_dbg(adapter, ERROR,
 				    "Unable to allocate skb for RX ring.\n");
 			kfree(card->rxbd_ring_vbase);
+			card->rxbd_ring_vbase = NULL;
 			return -ENOMEM;
 		}
 
@@ -1632,8 +1633,10 @@ static int mwifiex_pcie_process_recv_data(struct mwifiex_adapter *adapter)
 
 		if (mwifiex_map_pci_memory(adapter, skb_tmp,
 					   MWIFIEX_RX_DATA_BUF_SIZE,
-					   DMA_FROM_DEVICE))
+					   DMA_FROM_DEVICE)) {
+			dev_kfree_skb_any(skb);
 			return -1;
+		}
 
 		buf_pa = MWIFIEX_SKB_DMA_ADDR(skb_tmp);
 
diff --git a/drivers/scsi/fcoe/fcoe.c b/drivers/scsi/fcoe/fcoe.c
index 0f9274960..f4041587c
--- a/drivers/scsi/fcoe/fcoe.c
+++ b/drivers/scsi/fcoe/fcoe.c
@@ -830,6 +830,7 @@ static void fcoe_fdmi_info(struct fc_lport *lport, struct net_device *netdev)
 		if (rc) {
 			printk(KERN_INFO "fcoe: Failed to retrieve FDMI "
 					"information from netdev.\n");
+			kfree(fdmi);
 			return;
 		}
 
-- 
2.30.0

